package com.ruoyi.project.sems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.sems.mapper.TSpecdevAqfMapper;
import com.ruoyi.project.sems.domain.TSpecdevAqf;
import com.ruoyi.project.sems.service.ITSpecdevAqfService;

/**
 * 特种设备安全阀台账Service业务层处理
 *
 * @author ruoyi
 * @date 2022-09-28
 */
@Service
public class TSpecdevAqfServiceImpl implements ITSpecdevAqfService
{
    @Autowired
    private TSpecdevAqfMapper tSpecdevAqfMapper;

    /**
     * 查询特种设备安全阀台账
     *
     * @param id 特种设备安全阀台账ID
     * @return 特种设备安全阀台账
     */
    @Override
    public TSpecdevAqf selectTSpecdevAqfById(Long id)
    {
        return tSpecdevAqfMapper.selectTSpecdevAqfById(id);
    }

    /**
     * 查询特种设备安全阀台账列表
     *
     * @param tSpecdevAqf 特种设备安全阀台账
     * @return 特种设备安全阀台账
     */
    @Override
    public List<TSpecdevAqf> selectTSpecdevAqfList(TSpecdevAqf tSpecdevAqf)
    {
        return tSpecdevAqfMapper.selectTSpecdevAqfList(tSpecdevAqf);
    }

    /**
     * 新增特种设备安全阀台账
     *
     * @param tSpecdevAqf 特种设备安全阀台账
     * @return 结果
     */
    @Override
    public int insertTSpecdevAqf(TSpecdevAqf tSpecdevAqf)
    {
        return tSpecdevAqfMapper.insertTSpecdevAqf(tSpecdevAqf);
    }

    /**
     * 修改特种设备安全阀台账
     *
     * @param tSpecdevAqf 特种设备安全阀台账
     * @return 结果
     */
    @Override
    public int updateTSpecdevAqf(TSpecdevAqf tSpecdevAqf)
    {
        return tSpecdevAqfMapper.updateTSpecdevAqf(tSpecdevAqf);
    }

    /**
     * 批量删除特种设备安全阀台账
     *
     * @param ids 需要删除的特种设备安全阀台账ID
     * @return 结果
     */
    @Override
    public int deleteTSpecdevAqfByIds(Long[] ids)
    {
        return tSpecdevAqfMapper.deleteTSpecdevAqfByIds(ids);
    }

    /**
     * 删除特种设备安全阀台账信息
     *
     * @param id 特种设备安全阀台账ID
     * @return 结果
     */
    @Override
    public int deleteTSpecdevAqfById(Long id)
    {
        return tSpecdevAqfMapper.deleteTSpecdevAqfById(id);
    }  @Override
    public int deleteTSpecdevAqfByMainId(Long id)
    {
        return tSpecdevAqfMapper.deleteTSpecdevAqfByMainId(id);
    }
}
